@@ -21,7 +21,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -51,6 +51,10 @@ QueryLog directly.
 
 =head1 METHODS
 
+=head2 new
+
+Create a new DBIx::Class::QueryLog.
+
 =cut
 sub new {
     my $proto = shift();
@@ -120,12 +124,6 @@ sub reset {
 	$self->log(undef);
 }
 
-sub report {
-	my $self = shift();
-	
-	print Dumper($self);
-}
-
 =head2 add_to_log
 
 Add this provided Transaction or Query to the log.
